@@ -55,19 +55,23 @@ MM *mm_create(size_t usize, const char *file)
     MM *mm = NULL;
     void *core;
     size_t size;
+    size_t maxsize;
 
     /* defaults */
-    if (usize < 0)
+    maxsize = mm_maxsize();
+    if (usize < 0) {
+        errno = EINVAL;
         return NULL;
+    }
     if (usize == 0)
-        usize = MM_ALLOC_MAXSIZE;
-    if (usize <= MM_ALLOC_MINSIZE)
+        usize = maxsize;
+    if (usize > maxsize)
+        usize = maxsize;
+    if (usize < MM_ALLOC_MINSIZE)
         usize = MM_ALLOC_MINSIZE;
-    if (usize >= MM_ALLOC_MAXSIZE)
-        usize = MM_ALLOC_MAXSIZE;
 
     /* determine size */
-    size = mm_core_align2page(usize+SIZEOF_mem_pool);
+    size = usize+SIZEOF_mem_pool;
 
     /* get a shared memory area */
     if ((core = mm_core_create(size, file)) == NULL)
@@ -392,11 +396,11 @@ size_t mm_sizeof(MM *mm, const void *ptr)
 }
 
 /*
- * Determine maximum size of an allocateable memory poo
+ * Determine maximum size of an allocateable memory pool
  */
 size_t mm_maxsize(void)
 {
-    return MM_ALLOC_MAXSIZE;
+    return (mm_core_maxsegsize()-SIZEOF_mem_pool);
 }
 
 /*
